psychopy_ext.ui.Choices
=======================

.. currentmodule:: psychopy_ext.ui

.. autoclass:: Choices

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Choices.__init__
   
   

   
   
   